BatchPrediction class

Represents the output of a GetBatchPrediction operation.

The content consists of the detailed metadata, the status, and the data file information of a Batch Prediction.

Constructors

BatchPrediction({String? batchPredictionDataSourceId, String? batchPredictionId, int? computeTime, DateTime? createdAt, String? createdByIamUser, DateTime? finishedAt, String? inputDataLocationS3, int? invalidRecordCount, DateTime? lastUpdatedAt, String? mLModelId, String? message, String? name, String? outputUri, DateTime? startedAt, EntityStatus? status, int? totalRecordCount})
BatchPrediction.fromJson(Map<String, dynamic> json)
factory

Properties

batchPredictionDataSourceId → String?
The ID of the DataSource that points to the group of observations to predict.
final
batchPredictionId → String?
The ID assigned to the BatchPrediction at creation. This value should be identical to the value of the BatchPredictionID in the request.
final
computeTime → int?
final
createdAt → DateTime?
The time that the BatchPrediction was created. The time is expressed in epoch time.
final
createdByIamUser → String?
The AWS user account that invoked the BatchPrediction. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
final
finishedAt → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
inputDataLocationS3 → String?
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
final
invalidRecordCount → int?
final
lastUpdatedAt → DateTime?
The time of the most recent edit to the BatchPrediction. The time is expressed in epoch time.
final
message → String?
A description of the most recent details about processing the batch prediction request.
final
mLModelId → String?
The ID of the MLModel that generated predictions for the BatchPrediction request.
final
name → String?
A user-supplied name or description of the BatchPrediction.
final
outputUri → String?
The location of an Amazon S3 bucket or directory to receive the operation results. The following substrings are not allowed in the s3 key portion of the outputURI field: ':', '//', '/./', '/../'.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startedAt → DateTime?
final
status → EntityStatus?
The status of the BatchPrediction. This element can have one of the following values:
final
totalRecordCount → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited