DataSource class

Represents the output of the GetDataSource operation.

The content consists of the detailed metadata and data file information and the current status of the DataSource.

Constructors

DataSource({bool? computeStatistics, int? computeTime, DateTime? createdAt, String? createdByIamUser, String? dataLocationS3, String? dataRearrangement, int? dataSizeInBytes, String? dataSourceId, DateTime? finishedAt, DateTime? lastUpdatedAt, String? message, String? name, int? numberOfFiles, RDSMetadata? rDSMetadata, RedshiftMetadata? redshiftMetadata, String? roleARN, DateTime? startedAt, EntityStatus? status})
DataSource.fromJson(Map<String, dynamic> json)
factory

Properties

computeStatistics → bool?
The parameter is true if statistics need to be generated from the observation data.
final
computeTime → int?
final
createdAt → DateTime?
The time that the DataSource was created. The time is expressed in epoch time.
final
createdByIamUser → String?
The AWS user account from which the DataSource was created. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
final
dataLocationS3 → String?
The location and name of the data in Amazon Simple Storage Service (Amazon S3) that is used by a DataSource.
final
dataRearrangement → String?
A JSON string that represents the splitting and rearrangement requirement used when this DataSource was created.
final
dataSizeInBytes → int?
The total number of observations contained in the data files that the DataSource references.
final
dataSourceId → String?
The ID that is assigned to the DataSource during creation.
final
finishedAt → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
lastUpdatedAt → DateTime?
The time of the most recent edit to the BatchPrediction. The time is expressed in epoch time.
final
message → String?
A description of the most recent details about creating the DataSource.
final
name → String?
A user-supplied name or description of the DataSource.
final
numberOfFiles → int?
The number of data files referenced by the DataSource.
final
rDSMetadata → RDSMetadata?
final
redshiftMetadata → RedshiftMetadata?
final
roleARN → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startedAt → DateTime?
final
status → EntityStatus?
The current status of the DataSource. This element can have one of the following values:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited