DeleteDataSourceOutput class

Represents the output of a DeleteDataSource operation.

Constructors

DeleteDataSourceOutput({String? dataSourceId})
DeleteDataSourceOutput.fromJson(Map<String, dynamic> json)
factory

Properties

dataSourceId → String?
A user-supplied ID that uniquely identifies the DataSource. This value should be identical to the value of the DataSourceID in the request.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited