DeleteMLModelOutput class

Represents the output of a DeleteMLModel operation.

You can use the GetMLModel operation and check the value of the Status parameter to see whether an MLModel is marked as DELETED.

Constructors

DeleteMLModelOutput({String? mLModelId})
DeleteMLModelOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
mLModelId → String?
A user-supplied ID that uniquely identifies the MLModel. This value should be identical to the value of the MLModelID in the request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited