DeleteRealtimeEndpointOutput class

Represents the output of an DeleteRealtimeEndpoint operation.

The result contains the MLModelId and the endpoint information for the MLModel.

Constructors

DeleteRealtimeEndpointOutput({String? mLModelId, RealtimeEndpointInfo? realtimeEndpointInfo})
DeleteRealtimeEndpointOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
mLModelId → String?
A user-supplied ID that uniquely identifies the MLModel. This value should be identical to the value of the MLModelId in the request.
final
realtimeEndpointInfo → RealtimeEndpointInfo?
The endpoint information of the MLModel
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited