DescribeBatchPredictionsOutput class

Represents the output of a DescribeBatchPredictions operation. The content is essentially a list of BatchPredictions.

Constructors

DescribeBatchPredictionsOutput({String? nextToken, List<BatchPrediction>? results})
DescribeBatchPredictionsOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The ID of the next page in the paginated results that indicates at least one more page follows.
final
results → List<BatchPrediction>?
A list of BatchPrediction objects that meet the search criteria.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited