DescribeEvaluationsOutput class

Represents the query results from a DescribeEvaluations operation. The content is essentially a list of Evaluation.

Constructors

DescribeEvaluationsOutput({String? nextToken, List<Evaluation>? results})
DescribeEvaluationsOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
The ID of the next page in the paginated results that indicates at least one more page follows.
final
results → List<Evaluation>?
A list of Evaluation that meet the search criteria.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited