Evaluation class

Represents the output of GetEvaluation operation.

The content consists of the detailed metadata and data file information and the current status of the Evaluation.

Constructors

Evaluation({int? computeTime, DateTime? createdAt, String? createdByIamUser, String? evaluationDataSourceId, String? evaluationId, DateTime? finishedAt, String? inputDataLocationS3, DateTime? lastUpdatedAt, String? mLModelId, String? message, String? name, PerformanceMetrics? performanceMetrics, DateTime? startedAt, EntityStatus? status})
Evaluation.fromJson(Map<String, dynamic> json)
factory

Properties

computeTime → int?
final
createdAt → DateTime?
The time that the Evaluation was created. The time is expressed in epoch time.
final
createdByIamUser → String?
The AWS user account that invoked the evaluation. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
final
evaluationDataSourceId → String?
The ID of the DataSource that is used to evaluate the MLModel.
final
evaluationId → String?
The ID that is assigned to the Evaluation at creation.
final
finishedAt → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
inputDataLocationS3 → String?
The location and name of the data in Amazon Simple Storage Server (Amazon S3) that is used in the evaluation.
final
lastUpdatedAt → DateTime?
The time of the most recent edit to the Evaluation. The time is expressed in epoch time.
final
message → String?
A description of the most recent details about evaluating the MLModel.
final
mLModelId → String?
The ID of the MLModel that is the focus of the evaluation.
final
name → String?
A user-supplied name or description of the Evaluation.
final
performanceMetrics → PerformanceMetrics?
Measurements of how well the MLModel performed, using observations referenced by the DataSource. One of the following metrics is returned, based on the type of the MLModel:
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startedAt → DateTime?
final
status → EntityStatus?
The status of the evaluation. This element can have one of the following values:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited