GetBatchPredictionOutput class

Represents the output of a GetBatchPrediction operation and describes a BatchPrediction.

Constructors

GetBatchPredictionOutput({String? batchPredictionDataSourceId, String? batchPredictionId, int? computeTime, DateTime? createdAt, String? createdByIamUser, DateTime? finishedAt, String? inputDataLocationS3, int? invalidRecordCount, DateTime? lastUpdatedAt, String? logUri, String? mLModelId, String? message, String? name, String? outputUri, DateTime? startedAt, EntityStatus? status, int? totalRecordCount})
GetBatchPredictionOutput.fromJson(Map<String, dynamic> json)
factory

Properties

batchPredictionDataSourceId → String?
The ID of the DataSource that was used to create the BatchPrediction.
final
batchPredictionId → String?
An ID assigned to the BatchPrediction at creation. This value should be identical to the value of the BatchPredictionID in the request.
final
computeTime → int?
The approximate CPU time in milliseconds that Amazon Machine Learning spent processing the BatchPrediction, normalized and scaled on computation resources. ComputeTime is only available if the BatchPrediction is in the COMPLETED state.
final
createdAt → DateTime?
The time when the BatchPrediction was created. The time is expressed in epoch time.
final
createdByIamUser → String?
The AWS user account that invoked the BatchPrediction. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
final
finishedAt → DateTime?
The epoch time when Amazon Machine Learning marked the BatchPrediction as COMPLETED or FAILED. FinishedAt is only available when the BatchPrediction is in the COMPLETED or FAILED state.
final
hashCode → int
The hash code for this object.
no setterinherited
inputDataLocationS3 → String?
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
final
invalidRecordCount → int?
The number of invalid records that Amazon Machine Learning saw while processing the BatchPrediction.
final
lastUpdatedAt → DateTime?
The time of the most recent edit to BatchPrediction. The time is expressed in epoch time.
final
logUri → String?
A link to the file that contains logs of the CreateBatchPrediction operation.
final
message → String?
A description of the most recent details about processing the batch prediction request.
final
mLModelId → String?
The ID of the MLModel that generated predictions for the BatchPrediction request.
final
name → String?
A user-supplied name or description of the BatchPrediction.
final
outputUri → String?
The location of an Amazon S3 bucket or directory to receive the operation results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startedAt → DateTime?
The epoch time when Amazon Machine Learning marked the BatchPrediction as INPROGRESS. StartedAt isn't available if the BatchPrediction is in the PENDING state.
final
status → EntityStatus?
The status of the BatchPrediction, which can be one of the following values:
final
totalRecordCount → int?
The number of total records that Amazon Machine Learning saw while processing the BatchPrediction.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited