GetEvaluationOutput class

Represents the output of a GetEvaluation operation and describes an Evaluation.

Constructors

GetEvaluationOutput({int? computeTime, DateTime? createdAt, String? createdByIamUser, String? evaluationDataSourceId, String? evaluationId, DateTime? finishedAt, String? inputDataLocationS3, DateTime? lastUpdatedAt, String? logUri, String? mLModelId, String? message, String? name, PerformanceMetrics? performanceMetrics, DateTime? startedAt, EntityStatus? status})
GetEvaluationOutput.fromJson(Map<String, dynamic> json)
factory

Properties

computeTime → int?
The approximate CPU time in milliseconds that Amazon Machine Learning spent processing the Evaluation, normalized and scaled on computation resources. ComputeTime is only available if the Evaluation is in the COMPLETED state.
final
createdAt → DateTime?
The time that the Evaluation was created. The time is expressed in epoch time.
final
createdByIamUser → String?
The AWS user account that invoked the evaluation. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
final
evaluationDataSourceId → String?
The DataSource used for this evaluation.
final
evaluationId → String?
The evaluation ID which is same as the EvaluationId in the request.
final
finishedAt → DateTime?
The epoch time when Amazon Machine Learning marked the Evaluation as COMPLETED or FAILED. FinishedAt is only available when the Evaluation is in the COMPLETED or FAILED state.
final
hashCode → int
The hash code for this object.
no setterinherited
inputDataLocationS3 → String?
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
final
lastUpdatedAt → DateTime?
The time of the most recent edit to the Evaluation. The time is expressed in epoch time.
final
logUri → String?
A link to the file that contains logs of the CreateEvaluation operation.
final
message → String?
A description of the most recent details about evaluating the MLModel.
final
mLModelId → String?
The ID of the MLModel that was the focus of the evaluation.
final
name → String?
A user-supplied name or description of the Evaluation.
final
performanceMetrics → PerformanceMetrics?
Measurements of how well the MLModel performed using observations referenced by the DataSource. One of the following metric is returned based on the type of the MLModel:
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startedAt → DateTime?
The epoch time when Amazon Machine Learning marked the Evaluation as INPROGRESS. StartedAt isn't available if the Evaluation is in the PENDING state.
final
status → EntityStatus?
The status of the evaluation. This element can have one of the following values:
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited