GetMLModelOutput class

Represents the output of a GetMLModel operation, and provides detailed information about a MLModel.

Constructors

GetMLModelOutput({int? computeTime, DateTime? createdAt, String? createdByIamUser, RealtimeEndpointInfo? endpointInfo, DateTime? finishedAt, String? inputDataLocationS3, DateTime? lastUpdatedAt, String? logUri, String? mLModelId, MLModelType? mLModelType, String? message, String? name, String? recipe, String? schema, double? scoreThreshold, DateTime? scoreThresholdLastUpdatedAt, int? sizeInBytes, DateTime? startedAt, EntityStatus? status, String? trainingDataSourceId, Map<String, String>? trainingParameters})
GetMLModelOutput.fromJson(Map<String, dynamic> json)
factory

Properties

computeTime → int?
The approximate CPU time in milliseconds that Amazon Machine Learning spent processing the MLModel, normalized and scaled on computation resources. ComputeTime is only available if the MLModel is in the COMPLETED state.
final
createdAt → DateTime?
The time that the MLModel was created. The time is expressed in epoch time.
final
createdByIamUser → String?
The AWS user account from which the MLModel was created. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
final
endpointInfo → RealtimeEndpointInfo?
The current endpoint of the MLModel
final
finishedAt → DateTime?
The epoch time when Amazon Machine Learning marked the MLModel as COMPLETED or FAILED. FinishedAt is only available when the MLModel is in the COMPLETED or FAILED state.
final
hashCode → int
The hash code for this object.
no setterinherited
inputDataLocationS3 → String?
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
final
lastUpdatedAt → DateTime?
The time of the most recent edit to the MLModel. The time is expressed in epoch time.
final
logUri → String?
A link to the file that contains logs of the CreateMLModel operation.
final
message → String?
A description of the most recent details about accessing the MLModel.
final
mLModelId → String?
The MLModel ID<?oxy_insert_start author="annbech" timestamp="20160328T151251-0700">,<?oxy_insert_end> which is same as the MLModelId in the request.
final
mLModelType → MLModelType?
Identifies the MLModel category. The following are the available types:
final
name → String?
A user-supplied name or description of the MLModel.
final
recipe → String?
The recipe to use when training the MLModel. The Recipe provides detailed information about the observation data to use during training, and manipulations to perform on the observation data during training.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema → String?
The schema used by all of the data files referenced by the DataSource.
final
scoreThreshold → double?
The scoring threshold is used in binary classification MLModel<?oxy_insert_start author="laurama" timestamp="20160329T114851-0700"> <?oxy_insert_end>models. It marks the boundary between a positive prediction and a negative prediction.
final
scoreThresholdLastUpdatedAt → DateTime?
The time of the most recent edit to the ScoreThreshold. The time is expressed in epoch time.
final
sizeInBytes → int?
final
startedAt → DateTime?
The epoch time when Amazon Machine Learning marked the MLModel as INPROGRESS. StartedAt isn't available if the MLModel is in the PENDING state.
final
status → EntityStatus?
The current status of the MLModel. This element can have one of the following values:
final
trainingDataSourceId → String?
The ID of the training DataSource.
final
trainingParameters → Map<String, String>?
A list of the training parameters in the MLModel. The list is implemented as a map of key-value pairs.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited