MLModel class

Represents the output of a GetMLModel operation.

The content consists of the detailed metadata and the current status of the MLModel.

Constructors

MLModel({Algorithm? algorithm, int? computeTime, DateTime? createdAt, String? createdByIamUser, RealtimeEndpointInfo? endpointInfo, DateTime? finishedAt, String? inputDataLocationS3, DateTime? lastUpdatedAt, String? mLModelId, MLModelType? mLModelType, String? message, String? name, double? scoreThreshold, DateTime? scoreThresholdLastUpdatedAt, int? sizeInBytes, DateTime? startedAt, EntityStatus? status, String? trainingDataSourceId, Map<String, String>? trainingParameters})
MLModel.fromJson(Map<String, dynamic> json)
factory

Properties

algorithm → Algorithm?
The algorithm used to train the MLModel. The following algorithm is supported:
final
computeTime → int?
final
createdAt → DateTime?
The time that the MLModel was created. The time is expressed in epoch time.
final
createdByIamUser → String?
The AWS user account from which the MLModel was created. The account type can be either an AWS root account or an AWS Identity and Access Management (IAM) user account.
final
endpointInfo → RealtimeEndpointInfo?
The current endpoint of the MLModel.
final
finishedAt → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
inputDataLocationS3 → String?
The location of the data file or directory in Amazon Simple Storage Service (Amazon S3).
final
lastUpdatedAt → DateTime?
The time of the most recent edit to the MLModel. The time is expressed in epoch time.
final
message → String?
A description of the most recent details about accessing the MLModel.
final
mLModelId → String?
The ID assigned to the MLModel at creation.
final
mLModelType → MLModelType?
Identifies the MLModel category. The following are the available types:
final
name → String?
A user-supplied name or description of the MLModel.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scoreThreshold → double?
final
scoreThresholdLastUpdatedAt → DateTime?
The time of the most recent edit to the ScoreThreshold. The time is expressed in epoch time.
final
sizeInBytes → int?
final
startedAt → DateTime?
final
status → EntityStatus?
The current status of an MLModel. This element can have one of the following values:
final
trainingDataSourceId → String?
The ID of the training DataSource. The CreateMLModel operation uses the TrainingDataSourceId.
final
trainingParameters → Map<String, String>?
A list of the training parameters in the MLModel. The list is implemented as a map of key-value pairs.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited