RDSDatabase class

The database details of an Amazon RDS database.

Constructors

RDSDatabase({required String databaseName, required String instanceIdentifier})
RDSDatabase.fromJson(Map<String, dynamic> json)
factory

Properties

databaseName → String
final
hashCode → int
The hash code for this object.
no setterinherited
instanceIdentifier → String
The ID of an RDS DB instance.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited