RDSDatabaseCredentials class

The database credentials to connect to a database on an RDS DB instance.

Constructors

RDSDatabaseCredentials({required String password, required String username})

Properties

hashCode → int
The hash code for this object.
no setterinherited
password → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited