RedshiftDataSpec class

Describes the data specification of an Amazon Redshift DataSource.

Constructors

RedshiftDataSpec({required RedshiftDatabaseCredentials databaseCredentials, required RedshiftDatabase databaseInformation, required String s3StagingLocation, required String selectSqlQuery, String? dataRearrangement, String? dataSchema, String? dataSchemaUri})

Properties

databaseCredentials → RedshiftDatabaseCredentials
Describes AWS Identity and Access Management (IAM) credentials that are used connect to the Amazon Redshift database.
final
databaseInformation → RedshiftDatabase
Describes the DatabaseName and ClusterIdentifier for an Amazon Redshift DataSource.
final
dataRearrangement → String?
A JSON string that represents the splitting and rearrangement processing to be applied to a DataSource. If the DataRearrangement parameter is not provided, all of the input data is used to create the Datasource.
final
dataSchema → String?
A JSON string that represents the schema for an Amazon Redshift DataSource. The DataSchema defines the structure of the observation data in the data file(s) referenced in the DataSource.
final
dataSchemaUri → String?
Describes the schema location for an Amazon Redshift DataSource.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
s3StagingLocation → String
Describes an Amazon S3 location to store the result set of the SelectSqlQuery query.
final
selectSqlQuery → String
Describes the SQL Query to execute on an Amazon Redshift database for an Amazon Redshift DataSource.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited