RedshiftMetadata class

Describes the DataSource details specific to Amazon Redshift.

Constructors

RedshiftMetadata({String? databaseUserName, RedshiftDatabase? redshiftDatabase, String? selectSqlQuery})
RedshiftMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

databaseUserName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
redshiftDatabase → RedshiftDatabase?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectSqlQuery → String?
The SQL query that is specified during CreateDataSourceFromRedshift. Returns only if Verbose is true in GetDataSourceInput.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited