S3DataSpec class

Describes the data specification of a DataSource.

Constructors

S3DataSpec({required String dataLocationS3, String? dataRearrangement, String? dataSchema, String? dataSchemaLocationS3})

Properties

dataLocationS3 → String
The location of the data file(s) used by a DataSource. The URI specifies a data file or an Amazon Simple Storage Service (Amazon S3) directory or bucket containing data files.
final
dataRearrangement → String?
A JSON string that represents the splitting and rearrangement processing to be applied to a DataSource. If the DataRearrangement parameter is not provided, all of the input data is used to create the Datasource.
final
dataSchema → String?
A JSON string that represents the schema for an Amazon S3 DataSource. The DataSchema defines the structure of the observation data in the data file(s) referenced in the DataSource.
final
dataSchemaLocationS3 → String?
Describes the schema location in Amazon S3. You must provide either the DataSchema or the DataSchemaLocationS3.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited