UpdateDataSourceOutput class

Represents the output of an UpdateDataSource operation.

You can see the updated content by using the GetBatchPrediction operation.

Constructors

UpdateDataSourceOutput({String? dataSourceId})
UpdateDataSourceOutput.fromJson(Map<String, dynamic> json)
factory

Properties

dataSourceId → String?
The ID assigned to the DataSource during creation. This value should be identical to the value of the DataSourceID in the request.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited